summaryrefslogtreecommitdiffstats
path: root/cervisia/entry_status.h
diff options
context:
space:
mode:
Diffstat (limited to 'cervisia/entry_status.h')
-rw-r--r--cervisia/entry_status.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/cervisia/entry_status.h b/cervisia/entry_status.h
index b1d6cf6f..aa964735 100644
--- a/cervisia/entry_status.h
+++ b/cervisia/entry_status.h
@@ -31,7 +31,7 @@ namespace Cervisia
/**
* All stati a an entry could have.
*/
-enum EntrytqStatus
+enum EntryStatus
{
LocallyModified,
LocallyAdded,
@@ -51,11 +51,11 @@ enum EntrytqStatus
/**
* The entry status as translated string.
*
* @param entrytqStatus The entry status to translate.
*
* @return The translated string.
*/
-TQString toString(EntrytqStatus entrytqStatus);
+TQString toString(EntryStatus entryStatus);
} // namespace Cervisia
@@ -51,11 +51,11 @@ enum EntrytqStatus
* The entry status as translated string.
*
- * @param entrytqStatus The entry status to translate.
+ * @param entryStatus The entry status to translate.
*
* @return The translated string.